==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebRowSelectionEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebRowSelectionEventArgsDetailDescription } from "./WebRowSelectionEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebRowSelectionEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRowSelectionEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebRowSelectionEventArgsDetailDescriptionMetadata.a == null) {
                WebRowSelectionEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRowSelectionEventArgsDetailDescriptionMetadata.c(WebRowSelectionEventArgsDetailDescriptionMetadata.a);
            }
            if (a.j(WebRowSelectionEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.y(WebRowSelectionEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:RowSelectionEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("OldSelectionRef", "(w:OldSelection,wf:OldSelection)DataRef:object");
            a.item("NewSelectionRef", "(w:NewSelection,wf:NewSelection)DataRef:object");
            a.item("AddedRef", "(w:Added,wf:Added)DataRef:object");
            a.item("RemovedRef", "(w:Removed,wf:Removed)DataRef:object");
        }
        static d(a) {
            WebRowSelectionEventArgsDetailDescriptionMetadata.b(a);
            a.aa("WebRowSelectionEventArgsDetail", () => new WebRowSelectionEventArgsDetailDescription());
            a.z("WebRowSelectionEventArgsDetail", WebRowSelectionEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebRowSelectionEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebRowSelectionEventArgsDetailDescriptionMetadata, 'WebRowSelectionEventArgsDetailDescriptionMetadata');
    WebRowSelectionEventArgsDetailDescriptionMetadata.a = null;
    return WebRowSelectionEventArgsDetailDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebRowSelectionEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebRowSelectionEventArgsDetailDescription } from "./WebRowSelectionEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebRowSelectionEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRowSelectionEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebRowSelectionEventArgsDetailDescriptionMetadata.a == null) {
                WebRowSelectionEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRowSelectionEventArgsDetailDescriptionMetadata.c(WebRowSelectionEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebRowSelectionEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebRowSelectionEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:RowSelectionEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("OldSelectionRef", "(w:OldSelection,wf:OldSelection)DataRef:object");
            a.item("NewSelectionRef", "(w:NewSelection,wf:NewSelection)DataRef:object");
            a.item("AddedRef", "(w:Added,wf:Added)DataRef:object");
            a.item("RemovedRef", "(w:Removed,wf:Removed)DataRef:object");
            a.item("AllRowsSelected", "Boolean");
        }
        static d(a) {
            WebRowSelectionEventArgsDetailDescriptionMetadata.b(a);
            a.ac("WebRowSelectionEventArgsDetail", () => new WebRowSelectionEventArgsDetailDescription());
            a.ab("WebRowSelectionEventArgsDetail", WebRowSelectionEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebRowSelectionEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebRowSelectionEventArgsDetailDescriptionMetadata, 'WebRowSelectionEventArgsDetailDescriptionMetadata');
    WebRowSelectionEventArgsDetailDescriptionMetadata.a = null;
    return WebRowSelectionEventArgsDetailDescriptionMetadata;
})();
